@@ -1,5 +1,5 @@
 /* 
- * Copyright 1999-2008, Gisle Aas
+ * Copyright 1999-2009, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -658,7 +658,7 @@ IGNORE_EVENT:
 	else {
 	    SV *tmp = newSVpvn(beg, end - beg);
 	    sv_utf8_upgrade(tmp);
-	    sv_catsv(p_state->pend_text, tmp);
+	    sv_catsv(p_state->skipped_text, tmp);
 	    SvREFCNT_dec(tmp);
 	}
 #endif
@@ -726,8 +726,12 @@ argspec_compile(SV* src, PSTATE* p_state)
 			p_state->skipped_text = newSVpvn("", 0);
                     }
                 }
-		if (a == ARG_ATTR || a == ARG_ATTRARR || a == ARG_DTEXT) {
-		    p_state->argspec_entity_decode++;
+		if (a == ARG_ATTR || a == ARG_ATTRARR) {
+		    if (p_state->argspec_entity_decode != ARG_DTEXT)
+			p_state->argspec_entity_decode = ARG_ATTR;
+		}
+		else if (a == ARG_DTEXT) {
+		    p_state->argspec_entity_decode = ARG_DTEXT;
 		}
 	    }
 	    else {
@@ -1832,6 +1836,7 @@ parse(pTHX_
 	    /* Print warnings if we find unexpected Unicode BOM forms */
 #ifdef UNICODE_HTML_PARSER
 	    if (p_state->argspec_entity_decode &&
+		!(p_state->attr_encoded && p_state->argspec_entity_decode == ARG_ATTR) &&
 		!p_state->utf8_mode && (
                  (!utf8 && len >= 3 && strnEQ(beg, "\xEF\xBB\xBF", 3)) ||
 		 (utf8 && len >= 6 && strnEQ(beg, "\xC3\xAF\xC2\xBB\xC2\xBF", 6)) ||
